#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 microlens-aeson
version:              2.5.2
visibility:           public
id:                   microlens-aeson-2.5.2-21nZRCkdV0u9VCU4NhDuHi
key:                  microlens-aeson-2.5.2-21nZRCkdV0u9VCU4NhDuHi
license:              MIT
copyright:
    Copyright (C) 2012 Paul Wilson, (C) 2013 Edward A. Kmett, (C) 2015 Colin Woodbury

maintainer:           Colin Woodbury <colin@fosskers.ca>
author:               Colin Woodbury
homepage:             http://github.com/fosskers/microlens-aeson/
synopsis:             Law-abiding lenses for Aeson, using microlens
description:          Law-abiding lenses for Aeson, using microlens.
category:             Numeric
abi:                  54df6057a43e697e33d1183700dfb31e
exposed:              True
exposed-modules:      Lens.Micro.Aeson
hidden-modules:       Lens.Micro.Aeson.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/microlens-aeson-2.5.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/microlens-aeson-2.5.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/microlens-aeson-2.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-microlens-aeson
hs-libraries:         HSmicrolens-aeson-2.5.2-21nZRCkdV0u9VCU4NhDuHi
depends:
    aeson-2.2.2.0-CRLoVrOByflKEQQ5tNkVEn
    attoparsec-0.14.4-HFulVz6SrFwG1FlMeqAukh base-4.18.2.1
    bytestring-0.11.5.3 hashable-1.4.7.0-D6t6qvvDqS783ayXdNNEFV
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    scientific-0.3.8.1-31CWcid3qo6Aj4OF43pUKd text-2.0.2
    vector-0.13.2.0-LuonB4ieSbk1FHCVO4HoCK

haddock-interfaces:
    /usr/share/doc/haskell-microlens-aeson/html/microlens-aeson.haddock

haddock-html:         /usr/share/doc/haskell-microlens-aeson/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

